﻿LiveMap = {};

function LiveMap:loadMap(name)
    local version = "v1.1.1"
    local config = loadXMLFile("config",getUserProfileAppPath().."mods/liveMapConfig/liveMapConfig.xml");
    self.ModActive = Utils.getNoNil(getXMLBool(config,"liveMapConfig#active"),false);
    self.useOldOption = false;
    if self.ModActive then
        print("Loading Live Map mod "..version.."...");
        self.saveIntB = getXMLInt(config,"liveMapConfig.updateIntervall");
        if self.saveIntB < 5000 then
            self.saveIntB = 5000;
        end;
        local option = getXMLBool(config,"liveMapConfig.URLOption.active");
        self.InfosPath = "";
        if option then
            self.useOldOption = true;
            self.InfosPath = tostring(getUserProfileAppPath().."dedicated_server/gameStats.xml");
        else
            if getXMLBool(config,"liveMapConfig.MapInfoFile.UseMyGamesPath") then
                self.InfosPath = tostring(getUserProfileAppPath().."infos.xml");
            else
                self.InfosPath = getXMLString(config,"liveMapConfig.MapInfoFile.MapInfosPath");
            end;
        end;
        if not self.useOldOption then
            local file = io.open(getUserProfileAppPath().."infosSample.xml", "w");
            if file ~= nil then
                file:write("<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\" ?>\n");
                file:write("<Server>");
                file:write("</Server>");
            end
            file:close()
            local sourceFile = getUserProfileAppPath().."infosSample.xml";
            copyFile(sourceFile,self.InfosPath,true);
        end;
        self.NewxmlFile = loadXMLFile("livemap",self.InfosPath)
        setXMLString(self.NewxmlFile,"Server.state#online","true");
        setXMLString(self.NewxmlFile,"Server.state#capacity",tostring(g_currentMission.missionDynamicInfo.capacity));
        setXMLString(self.NewxmlFile,"Server.state#players","0");
        setXMLString(self.NewxmlFile,"Server.state#pause","true");
        setXMLString(self.NewxmlFile,"Server.state#time",tostring(g_currentMission.environment.dayTime)); 
        saveXMLFile(self.NewxmlFile);
        self.saveInt = self.saveIntB;
        print("Live Map Mod "..version.." loaded.");
    end;
    delete(config);
    delete(self.NewxmlFile);
end;

function LiveMap:deleteMap()
    if self.ModActive then
        if not self.useOldOption then
            local sourceFile = getUserProfileAppPath().."infosSample.xml";
            copyFile(sourceFile,self.InfosPath,true);
        end;
        self.NewxmlFile = loadXMLFile("livemap",self.InfosPath)
        setXMLString(self.NewxmlFile,"Server.state#online","false");
        setXMLString(self.NewxmlFile,"Server.state#capacity","0");
        setXMLString(self.NewxmlFile,"Server.state#players","0");
        setXMLString(self.NewxmlFile,"Server.state#pause","false");
        setXMLString(self.NewxmlFile,"Server.state#time","0")
        saveXMLFile(self.NewxmlFile);
        delete(self.NewxmlFile);
    end;
end;

function LiveMap:mouseEvent(posX, posY, isDown, isUp, button)
end;

function LiveMap:keyEvent(unicode, sym, modifier, isDown)
end;

function LiveMap:update(dt)
    if self.ModActive then
        self.saveInt = (self.saveInt-dt);
        if self.saveInt <= 0 then
            if not self.useOldOption then
                local sourceFile = getUserProfileAppPath().."infosSample.xml";
                copyFile(sourceFile,self.InfosPath,true);
            end;
            self.NewxmlFile = loadXMLFile("livemap",self.InfosPath)
            setXMLString(self.NewxmlFile,"Server.state#online","true");
            setXMLString(self.NewxmlFile,"Server.state#capacity",tostring(g_currentMission.missionDynamicInfo.capacity));
            setXMLString(self.NewxmlFile,"Server.state#players",tostring(table.getn(g_currentMission.users)));
            setXMLString(self.NewxmlFile,"Server.state#pause",tostring(g_currentMission.paused));
            setXMLString(self.NewxmlFile,"Server.state#time",tostring(g_currentMission.environment.dayTime));
            local ii = 1;
            local players = 0;
            for i,player in pairs(g_currentMission.players) do
                setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#name",tostring(player.controllerName));
                setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#type","Spieler");
                setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#controller","");
                if player.isControlled and not player.isEntered then
                    local x, y, z = getTranslation(player.rootNode)
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#x",tostring(x));
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#y",tostring(z));
                    players = players + 1;
                else
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#x","");
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#y","");
                end;
                ii = (ii+1);
            end;
            for i,vehicle in pairs(g_currentMission.vehicles) do
                if (vehicle.typeName ~= "trafficVehicle") then
                    local x,y,z = getWorldTranslation(vehicle.components[1].node);
                    local storeItem = StoreItemsUtil.storeItemsByXMLFilename[vehicle.configFileName:lower()];
                    if(storeItem ~= nil) and (storeItem.name ~= nil) then
                        setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#name",tostring(storeItem.name));
                    else
                        setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#name",tostring("Unbekannt"))
                    end;
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#type",tostring(vehicle.typeName));
                    local vehicleUser = vehicle.controllerName;
                    if not vehicle.isControlled then
                        vehicleUser = "";
                    else
                        players = players + 1; 
                    end;                    
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#controller",tostring(vehicleUser));
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#x",tostring(x));
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#y",tostring(z));
                else
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#name","");
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#type","");
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#controller","");
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#x","");
                    setXMLString(self.NewxmlFile,"Server.info("..tostring(ii)..")#y","");
                end;
                ii = ii + 1;
            end;
            if self.useOldOption then
                if ii < 500 then
                    for iii = ii, 500, 1 do
                        setXMLString(self.NewxmlFile,"Server.info("..tostring(iii)..")#name","");
                        setXMLString(self.NewxmlFile,"Server.info("..tostring(iii)..")#type","");
                        setXMLString(self.NewxmlFile,"Server.info("..tostring(iii)..")#controller","");
                        setXMLString(self.NewxmlFile,"Server.info("..tostring(iii)..")#x","");
                        setXMLString(self.NewxmlFile,"Server.info("..tostring(iii)..")#y","");
                    end;
                end;
            end;
            setXMLString(self.NewxmlFile,"Server.state#players",tostring(players));
            saveXMLFile(self.NewxmlFile);
            delete(self.NewxmlFile);
            self.saveInt = self.saveIntB;
        end;
    end;
end;

function LiveMap:draw()
end;
addModEventListener(LiveMap);